import type { User } from "oidc-client-ts";
import { type InjectionKey } from "vue";
/**
 * The auth state which, when combined with the auth methods, make up the return object of the `useAuth` hook.
 *
 * @public
 */
export interface AuthState {
    /**
     * See [User](https://authts.github.io/oidc-client-ts/classes/User.html) for more details.
     */
    user?: User | null;
    /**
     * True when the library has been initialized and no navigator request is in progress.
     */
    isLoading: boolean;
    /**
     * True while the user has a valid access token.
     */
    isAuthenticated: boolean;
    /**
     * Tracks the status of most recent signin/signout request method.
     */
    activeNavigator?: "signinRedirect" | "signinPopup" | "signinSilent" | "signoutRedirect" | "signoutPopup";
    /**
     * Was there a signin or silent renew error?
     */
    error?: Error;
}
declare type Action = {
    type: "INITIALISED" | "USER_LOADED";
    user: User | null;
} | {
    type: "USER_UNLOADED";
} | {
    type: "NAVIGATOR_INIT";
    method: NonNullable<AuthState["activeNavigator"]>;
} | {
    type: "NAVIGATOR_CLOSE";
} | {
    type: "ERROR";
    error: Error;
};
export declare const stateComputedRefs: {
    readonly user: import("vue").ComputedRef<{
        id_token?: string | undefined;
        session_state: string | null;
        access_token: string;
        refresh_token?: string | undefined;
        token_type: string;
        scope?: string | undefined;
        profile: {
            [x: string]: unknown;
            [x: number]: unknown;
            auth_time?: number | undefined;
            nonce?: string | undefined;
            acr?: string | undefined;
            amr?: unknown;
            azp?: string | undefined;
            sid?: string | undefined;
            sub: string;
            name?: string | undefined;
            profile?: string | undefined;
            given_name?: string | undefined;
            family_name?: string | undefined;
            middle_name?: string | undefined;
            nickname?: string | undefined;
            preferred_username?: string | undefined;
            picture?: string | undefined;
            website?: string | undefined;
            email?: string | undefined;
            email_verified?: boolean | undefined;
            gender?: string | undefined;
            birthdate?: string | undefined;
            zoneinfo?: string | undefined;
            locale?: string | undefined;
            phone_number?: string | undefined;
            phone_number_verified?: boolean | undefined;
            address?: {
                formatted?: string | undefined;
                street_address?: string | undefined;
                locality?: string | undefined;
                region?: string | undefined;
                postal_code?: string | undefined;
                country?: string | undefined;
            } | undefined;
            updated_at?: number | undefined;
            iss: string;
            aud: string | string[];
            exp: number;
            iat: number;
        };
        expires_at?: number | undefined;
        readonly state: unknown;
        expires_in: number | undefined;
        readonly expired: boolean | undefined;
        readonly scopes: string[];
        toStorageString: () => string;
    } | null | undefined>;
    readonly isLoading: import("vue").ComputedRef<boolean>;
    readonly isAuthenticated: import("vue").ComputedRef<boolean>;
    readonly activeNavigator: import("vue").ComputedRef<"signinRedirect" | "signinPopup" | "signinSilent" | "signoutRedirect" | "signoutPopup" | undefined>;
    readonly error: import("vue").ComputedRef<{
        name: string;
        message: string;
        stack?: string | undefined;
        cause?: any | undefined;
    } | undefined>;
};
export declare const useAuthStateReducer: () => readonly [{
    readonly user: import("vue").ComputedRef<{
        id_token?: string | undefined;
        session_state: string | null;
        access_token: string;
        refresh_token?: string | undefined;
        token_type: string;
        scope?: string | undefined;
        profile: {
            [x: string]: unknown;
            [x: number]: unknown;
            auth_time?: number | undefined;
            nonce?: string | undefined;
            acr?: string | undefined;
            amr?: unknown;
            azp?: string | undefined;
            sid?: string | undefined;
            sub: string;
            name?: string | undefined;
            profile?: string | undefined;
            given_name?: string | undefined;
            family_name?: string | undefined;
            middle_name?: string | undefined;
            nickname?: string | undefined;
            preferred_username?: string | undefined;
            picture?: string | undefined;
            website?: string | undefined;
            email?: string | undefined;
            email_verified?: boolean | undefined;
            gender?: string | undefined;
            birthdate?: string | undefined;
            zoneinfo?: string | undefined;
            locale?: string | undefined;
            phone_number?: string | undefined;
            phone_number_verified?: boolean | undefined;
            address?: {
                formatted?: string | undefined;
                street_address?: string | undefined;
                locality?: string | undefined;
                region?: string | undefined;
                postal_code?: string | undefined;
                country?: string | undefined;
            } | undefined;
            updated_at?: number | undefined;
            iss: string;
            aud: string | string[];
            exp: number;
            iat: number;
        };
        expires_at?: number | undefined;
        readonly state: unknown;
        expires_in: number | undefined;
        readonly expired: boolean | undefined;
        readonly scopes: string[];
        toStorageString: () => string;
    } | null | undefined>;
    readonly isLoading: import("vue").ComputedRef<boolean>;
    readonly isAuthenticated: import("vue").ComputedRef<boolean>;
    readonly activeNavigator: import("vue").ComputedRef<"signinRedirect" | "signinPopup" | "signinSilent" | "signoutRedirect" | "signoutPopup" | undefined>;
    readonly error: import("vue").ComputedRef<{
        name: string;
        message: string;
        stack?: string | undefined;
        cause?: any | undefined;
    } | undefined>;
}, (action: Action) => void];
export declare type AuthStateComputedRefs = typeof stateComputedRefs;
export declare const auth_state_key: InjectionKey<AuthStateComputedRefs>;
export declare const useAuthStateProvider: (state: AuthStateComputedRefs) => void;
export {};
